@@ -23,6 +23,7 @@ class EntityUrlMap:
     SECURITY = f'{_HOST_SECURITY}{_BASE_URL}security/'
     CONFIRMATION_ACCOUNT = f'{_HOST_SECURITY}{_BASE_URL}confirm_account/'
     CHAT = f'{_HOST_CHAT}{_BASE_URL}chat/'
-    INSTITUCION = f'{_HOST_INSTITUCION}{_BASE_URL}institucion/'
+    CONVERSATION = f'{_HOST_CHAT}{_BASE_URL}conversation/'
+    INSTITUCION = f'{_HOST_INSTITUCION}{_BASE_URL}institution/'
     PUBLICATION = f'{_HOST_PUBLICATION}{_BASE_URL}publication/'
     NOTIFICATION = f'{_HOST_NOTIFICATION}{_BASE_URL}notification/'
