@@ -29,6 +29,9 @@ class Enums:
     CONFIRMED = 'CONFIRMADO'
     FORCE_CHANGE_PASSWORD = 'FORZAR_CAMBIO_CONTRASEÑA'
     LIST_ACCOUNT_CONFIRMATION = [CONFIRMED, FORCE_CHANGE_PASSWORD]
+    GOOGLE_PROVIDER = 'Google'
+    REGULAR_PROVIDER = 'Regular'
+    LIST_PROVIDERS = [GOOGLE_PROVIDER, REGULAR_PROVIDER]
 
 
 class Constants:
